# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAgentPoolUpdateResult',
    'AwaitableGetAgentPoolUpdateResult',
    'get_agent_pool_update',
    'get_agent_pool_update_output',
]

@pulumi.output_type
class GetAgentPoolUpdateResult:
    """
    A collection of values returned by getAgentPoolUpdate.
    """
    def __init__(__self__, agent_type=None, agents=None, enabled=None, id=None, name=None, notify_admin=None, pool_id=None, reason=None, schedule=None, sort_order=None, status=None, target_version=None):
        if agent_type and not isinstance(agent_type, str):
            raise TypeError("Expected argument 'agent_type' to be a str")
        pulumi.set(__self__, "agent_type", agent_type)
        if agents and not isinstance(agents, list):
            raise TypeError("Expected argument 'agents' to be a list")
        pulumi.set(__self__, "agents", agents)
        if enabled and not isinstance(enabled, bool):
            raise TypeError("Expected argument 'enabled' to be a bool")
        pulumi.set(__self__, "enabled", enabled)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if notify_admin and not isinstance(notify_admin, bool):
            raise TypeError("Expected argument 'notify_admin' to be a bool")
        pulumi.set(__self__, "notify_admin", notify_admin)
        if pool_id and not isinstance(pool_id, str):
            raise TypeError("Expected argument 'pool_id' to be a str")
        pulumi.set(__self__, "pool_id", pool_id)
        if reason and not isinstance(reason, str):
            raise TypeError("Expected argument 'reason' to be a str")
        pulumi.set(__self__, "reason", reason)
        if schedule and not isinstance(schedule, dict):
            raise TypeError("Expected argument 'schedule' to be a dict")
        pulumi.set(__self__, "schedule", schedule)
        if sort_order and not isinstance(sort_order, int):
            raise TypeError("Expected argument 'sort_order' to be a int")
        pulumi.set(__self__, "sort_order", sort_order)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if target_version and not isinstance(target_version, str):
            raise TypeError("Expected argument 'target_version' to be a str")
        pulumi.set(__self__, "target_version", target_version)

    @_builtins.property
    @pulumi.getter(name="agentType")
    def agent_type(self) -> _builtins.str:
        """
        Agent types that are being monitored (e.g. AD, LDAP, IWA, RADIUS, MFA, OPP, RUM, Radius).
        """
        return pulumi.get(self, "agent_type")

    @_builtins.property
    @pulumi.getter
    def agents(self) -> Optional[Sequence['outputs.GetAgentPoolUpdateAgentResult']]:
        """
        The agents associated with the agent pool update.
        """
        return pulumi.get(self, "agents")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> _builtins.bool:
        """
        Indicates if auto-update is enabled for the agent pool.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier of the agent pool update.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the agent pool update.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="notifyAdmin")
    def notify_admin(self) -> _builtins.bool:
        """
        Indicates if the admin is notified about the update.
        """
        return pulumi.get(self, "notify_admin")

    @_builtins.property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> _builtins.str:
        """
        The unique identifier of the agent pool.
        """
        return pulumi.get(self, "pool_id")

    @_builtins.property
    @pulumi.getter
    def reason(self) -> _builtins.str:
        """
        Reason for the update.
        """
        return pulumi.get(self, "reason")

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> Optional['outputs.GetAgentPoolUpdateScheduleResult']:
        """
        The schedule configuration for the agent pool update.
        """
        return pulumi.get(self, "schedule")

    @_builtins.property
    @pulumi.getter(name="sortOrder")
    def sort_order(self) -> _builtins.int:
        """
        Specifies the sort order.
        """
        return pulumi.get(self, "sort_order")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        Overall state for the auto-update job from the admin perspective (e.g., Cancelled, Failed, InProgress, Paused, Scheduled, Success).
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="targetVersion")
    def target_version(self) -> _builtins.str:
        """
        The agent version to update to.
        """
        return pulumi.get(self, "target_version")


class AwaitableGetAgentPoolUpdateResult(GetAgentPoolUpdateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAgentPoolUpdateResult(
            agent_type=self.agent_type,
            agents=self.agents,
            enabled=self.enabled,
            id=self.id,
            name=self.name,
            notify_admin=self.notify_admin,
            pool_id=self.pool_id,
            reason=self.reason,
            schedule=self.schedule,
            sort_order=self.sort_order,
            status=self.status,
            target_version=self.target_version)


def get_agent_pool_update(agents: Optional[Sequence[Union['GetAgentPoolUpdateAgentArgs', 'GetAgentPoolUpdateAgentArgsDict']]] = None,
                          id: Optional[_builtins.str] = None,
                          pool_id: Optional[_builtins.str] = None,
                          schedule: Optional[Union['GetAgentPoolUpdateScheduleArgs', 'GetAgentPoolUpdateScheduleArgsDict']] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAgentPoolUpdateResult:
    """
    Retrieves an Okta Agent Pool Update. Agent pool updates allow you to schedule and manage updates for agent pools.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_agent_pool_update(id="<update_id>",
        pool_id="<pool_id>")
    ```


    :param Sequence[Union['GetAgentPoolUpdateAgentArgs', 'GetAgentPoolUpdateAgentArgsDict']] agents: The agents associated with the agent pool update.
    :param _builtins.str id: The unique identifier of the agent pool update.
    :param _builtins.str pool_id: The unique identifier of the agent pool.
    :param Union['GetAgentPoolUpdateScheduleArgs', 'GetAgentPoolUpdateScheduleArgsDict'] schedule: The schedule configuration for the agent pool update.
    """
    __args__ = dict()
    __args__['agents'] = agents
    __args__['id'] = id
    __args__['poolId'] = pool_id
    __args__['schedule'] = schedule
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getAgentPoolUpdate:getAgentPoolUpdate', __args__, opts=opts, typ=GetAgentPoolUpdateResult).value

    return AwaitableGetAgentPoolUpdateResult(
        agent_type=pulumi.get(__ret__, 'agent_type'),
        agents=pulumi.get(__ret__, 'agents'),
        enabled=pulumi.get(__ret__, 'enabled'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        notify_admin=pulumi.get(__ret__, 'notify_admin'),
        pool_id=pulumi.get(__ret__, 'pool_id'),
        reason=pulumi.get(__ret__, 'reason'),
        schedule=pulumi.get(__ret__, 'schedule'),
        sort_order=pulumi.get(__ret__, 'sort_order'),
        status=pulumi.get(__ret__, 'status'),
        target_version=pulumi.get(__ret__, 'target_version'))
def get_agent_pool_update_output(agents: Optional[pulumi.Input[Optional[Sequence[Union['GetAgentPoolUpdateAgentArgs', 'GetAgentPoolUpdateAgentArgsDict']]]]] = None,
                                 id: Optional[pulumi.Input[_builtins.str]] = None,
                                 pool_id: Optional[pulumi.Input[_builtins.str]] = None,
                                 schedule: Optional[pulumi.Input[Optional[Union['GetAgentPoolUpdateScheduleArgs', 'GetAgentPoolUpdateScheduleArgsDict']]]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAgentPoolUpdateResult]:
    """
    Retrieves an Okta Agent Pool Update. Agent pool updates allow you to schedule and manage updates for agent pools.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_agent_pool_update(id="<update_id>",
        pool_id="<pool_id>")
    ```


    :param Sequence[Union['GetAgentPoolUpdateAgentArgs', 'GetAgentPoolUpdateAgentArgsDict']] agents: The agents associated with the agent pool update.
    :param _builtins.str id: The unique identifier of the agent pool update.
    :param _builtins.str pool_id: The unique identifier of the agent pool.
    :param Union['GetAgentPoolUpdateScheduleArgs', 'GetAgentPoolUpdateScheduleArgsDict'] schedule: The schedule configuration for the agent pool update.
    """
    __args__ = dict()
    __args__['agents'] = agents
    __args__['id'] = id
    __args__['poolId'] = pool_id
    __args__['schedule'] = schedule
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getAgentPoolUpdate:getAgentPoolUpdate', __args__, opts=opts, typ=GetAgentPoolUpdateResult)
    return __ret__.apply(lambda __response__: GetAgentPoolUpdateResult(
        agent_type=pulumi.get(__response__, 'agent_type'),
        agents=pulumi.get(__response__, 'agents'),
        enabled=pulumi.get(__response__, 'enabled'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        notify_admin=pulumi.get(__response__, 'notify_admin'),
        pool_id=pulumi.get(__response__, 'pool_id'),
        reason=pulumi.get(__response__, 'reason'),
        schedule=pulumi.get(__response__, 'schedule'),
        sort_order=pulumi.get(__response__, 'sort_order'),
        status=pulumi.get(__response__, 'status'),
        target_version=pulumi.get(__response__, 'target_version')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ServerArgs', 'Server']

@pulumi.input_type
class ServerArgs:
    def __init__(__self__, *,
                 audiences: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 credentials_rotation_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 issuer_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Server resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] audiences: The recipients that the tokens are intended for. This becomes the `aud` claim in an access token. Currently Okta only supports a single value here.
        :param pulumi.Input[_builtins.str] credentials_rotation_mode: The key rotation mode for the authorization server. Can be `AUTO` or `MANUAL`. Default: `AUTO`
        :param pulumi.Input[_builtins.str] description: The description of the authorization server.
        :param pulumi.Input[_builtins.str] issuer_mode: *Early Access Property*. Allows you to use a custom issuer URL. It can be set to `CUSTOM_URL`, `ORG_URL`, or `DYNAMIC`. Default: `ORG_URL`
        :param pulumi.Input[_builtins.str] name: The name of the authorization server.
        :param pulumi.Input[_builtins.str] status: Default to `ACTIVE`
        """
        pulumi.set(__self__, "audiences", audiences)
        if credentials_rotation_mode is not None:
            pulumi.set(__self__, "credentials_rotation_mode", credentials_rotation_mode)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if issuer_mode is not None:
            pulumi.set(__self__, "issuer_mode", issuer_mode)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def audiences(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        The recipients that the tokens are intended for. This becomes the `aud` claim in an access token. Currently Okta only supports a single value here.
        """
        return pulumi.get(self, "audiences")

    @audiences.setter
    def audiences(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "audiences", value)

    @_builtins.property
    @pulumi.getter(name="credentialsRotationMode")
    def credentials_rotation_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The key rotation mode for the authorization server. Can be `AUTO` or `MANUAL`. Default: `AUTO`
        """
        return pulumi.get(self, "credentials_rotation_mode")

    @credentials_rotation_mode.setter
    def credentials_rotation_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "credentials_rotation_mode", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the authorization server.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="issuerMode")
    def issuer_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        *Early Access Property*. Allows you to use a custom issuer URL. It can be set to `CUSTOM_URL`, `ORG_URL`, or `DYNAMIC`. Default: `ORG_URL`
        """
        return pulumi.get(self, "issuer_mode")

    @issuer_mode.setter
    def issuer_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "issuer_mode", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the authorization server.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default to `ACTIVE`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _ServerState:
    def __init__(__self__, *,
                 audiences: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 credentials_last_rotated: Optional[pulumi.Input[_builtins.str]] = None,
                 credentials_next_rotation: Optional[pulumi.Input[_builtins.str]] = None,
                 credentials_rotation_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 issuer: Optional[pulumi.Input[_builtins.str]] = None,
                 issuer_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 kid: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Server resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] audiences: The recipients that the tokens are intended for. This becomes the `aud` claim in an access token. Currently Okta only supports a single value here.
        :param pulumi.Input[_builtins.str] credentials_last_rotated: The timestamp when the authorization server started to use the `kid` for signing tokens.
        :param pulumi.Input[_builtins.str] credentials_next_rotation: The timestamp when the authorization server changes the key for signing tokens. Only returned when `credentials_rotation_mode` is `AUTO`.
        :param pulumi.Input[_builtins.str] credentials_rotation_mode: The key rotation mode for the authorization server. Can be `AUTO` or `MANUAL`. Default: `AUTO`
        :param pulumi.Input[_builtins.str] description: The description of the authorization server.
        :param pulumi.Input[_builtins.str] issuer: The complete URL for a Custom Authorization Server. This becomes the `iss` claim in an access token.
        :param pulumi.Input[_builtins.str] issuer_mode: *Early Access Property*. Allows you to use a custom issuer URL. It can be set to `CUSTOM_URL`, `ORG_URL`, or `DYNAMIC`. Default: `ORG_URL`
        :param pulumi.Input[_builtins.str] kid: The ID of the JSON Web Key used for signing tokens issued by the authorization server.
        :param pulumi.Input[_builtins.str] name: The name of the authorization server.
        :param pulumi.Input[_builtins.str] status: Default to `ACTIVE`
        """
        if audiences is not None:
            pulumi.set(__self__, "audiences", audiences)
        if credentials_last_rotated is not None:
            pulumi.set(__self__, "credentials_last_rotated", credentials_last_rotated)
        if credentials_next_rotation is not None:
            pulumi.set(__self__, "credentials_next_rotation", credentials_next_rotation)
        if credentials_rotation_mode is not None:
            pulumi.set(__self__, "credentials_rotation_mode", credentials_rotation_mode)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if issuer is not None:
            pulumi.set(__self__, "issuer", issuer)
        if issuer_mode is not None:
            pulumi.set(__self__, "issuer_mode", issuer_mode)
        if kid is not None:
            pulumi.set(__self__, "kid", kid)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def audiences(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The recipients that the tokens are intended for. This becomes the `aud` claim in an access token. Currently Okta only supports a single value here.
        """
        return pulumi.get(self, "audiences")

    @audiences.setter
    def audiences(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "audiences", value)

    @_builtins.property
    @pulumi.getter(name="credentialsLastRotated")
    def credentials_last_rotated(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The timestamp when the authorization server started to use the `kid` for signing tokens.
        """
        return pulumi.get(self, "credentials_last_rotated")

    @credentials_last_rotated.setter
    def credentials_last_rotated(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "credentials_last_rotated", value)

    @_builtins.property
    @pulumi.getter(name="credentialsNextRotation")
    def credentials_next_rotation(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The timestamp when the authorization server changes the key for signing tokens. Only returned when `credentials_rotation_mode` is `AUTO`.
        """
        return pulumi.get(self, "credentials_next_rotation")

    @credentials_next_rotation.setter
    def credentials_next_rotation(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "credentials_next_rotation", value)

    @_builtins.property
    @pulumi.getter(name="credentialsRotationMode")
    def credentials_rotation_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The key rotation mode for the authorization server. Can be `AUTO` or `MANUAL`. Default: `AUTO`
        """
        return pulumi.get(self, "credentials_rotation_mode")

    @credentials_rotation_mode.setter
    def credentials_rotation_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "credentials_rotation_mode", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the authorization server.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def issuer(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The complete URL for a Custom Authorization Server. This becomes the `iss` claim in an access token.
        """
        return pulumi.get(self, "issuer")

    @issuer.setter
    def issuer(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "issuer", value)

    @_builtins.property
    @pulumi.getter(name="issuerMode")
    def issuer_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        *Early Access Property*. Allows you to use a custom issuer URL. It can be set to `CUSTOM_URL`, `ORG_URL`, or `DYNAMIC`. Default: `ORG_URL`
        """
        return pulumi.get(self, "issuer_mode")

    @issuer_mode.setter
    def issuer_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "issuer_mode", value)

    @_builtins.property
    @pulumi.getter
    def kid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the JSON Web Key used for signing tokens issued by the authorization server.
        """
        return pulumi.get(self, "kid")

    @kid.setter
    def kid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "kid", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the authorization server.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default to `ACTIVE`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("okta:auth/server:Server")
class Server(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 audiences: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 credentials_rotation_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 issuer_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates an Authorization Server. This resource allows you to create and configure an Authorization Server.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.auth.Server("example",
            audiences=["api://example"],
            description="My Example Auth Server",
            name="example",
            issuer_mode="CUSTOM_URL",
            status="ACTIVE")
        ```

        ## Import

        ```sh
        $ pulumi import okta:auth/server:Server example <auth_server_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] audiences: The recipients that the tokens are intended for. This becomes the `aud` claim in an access token. Currently Okta only supports a single value here.
        :param pulumi.Input[_builtins.str] credentials_rotation_mode: The key rotation mode for the authorization server. Can be `AUTO` or `MANUAL`. Default: `AUTO`
        :param pulumi.Input[_builtins.str] description: The description of the authorization server.
        :param pulumi.Input[_builtins.str] issuer_mode: *Early Access Property*. Allows you to use a custom issuer URL. It can be set to `CUSTOM_URL`, `ORG_URL`, or `DYNAMIC`. Default: `ORG_URL`
        :param pulumi.Input[_builtins.str] name: The name of the authorization server.
        :param pulumi.Input[_builtins.str] status: Default to `ACTIVE`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an Authorization Server. This resource allows you to create and configure an Authorization Server.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.auth.Server("example",
            audiences=["api://example"],
            description="My Example Auth Server",
            name="example",
            issuer_mode="CUSTOM_URL",
            status="ACTIVE")
        ```

        ## Import

        ```sh
        $ pulumi import okta:auth/server:Server example <auth_server_id>
        ```

        :param str resource_name: The name of the resource.
        :param ServerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 audiences: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 credentials_rotation_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 issuer_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServerArgs.__new__(ServerArgs)

            if audiences is None and not opts.urn:
                raise TypeError("Missing required property 'audiences'")
            __props__.__dict__["audiences"] = audiences
            __props__.__dict__["credentials_rotation_mode"] = credentials_rotation_mode
            __props__.__dict__["description"] = description
            __props__.__dict__["issuer_mode"] = issuer_mode
            __props__.__dict__["name"] = name
            __props__.__dict__["status"] = status
            __props__.__dict__["credentials_last_rotated"] = None
            __props__.__dict__["credentials_next_rotation"] = None
            __props__.__dict__["issuer"] = None
            __props__.__dict__["kid"] = None
        super(Server, __self__).__init__(
            'okta:auth/server:Server',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            audiences: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            credentials_last_rotated: Optional[pulumi.Input[_builtins.str]] = None,
            credentials_next_rotation: Optional[pulumi.Input[_builtins.str]] = None,
            credentials_rotation_mode: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            issuer: Optional[pulumi.Input[_builtins.str]] = None,
            issuer_mode: Optional[pulumi.Input[_builtins.str]] = None,
            kid: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None) -> 'Server':
        """
        Get an existing Server resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] audiences: The recipients that the tokens are intended for. This becomes the `aud` claim in an access token. Currently Okta only supports a single value here.
        :param pulumi.Input[_builtins.str] credentials_last_rotated: The timestamp when the authorization server started to use the `kid` for signing tokens.
        :param pulumi.Input[_builtins.str] credentials_next_rotation: The timestamp when the authorization server changes the key for signing tokens. Only returned when `credentials_rotation_mode` is `AUTO`.
        :param pulumi.Input[_builtins.str] credentials_rotation_mode: The key rotation mode for the authorization server. Can be `AUTO` or `MANUAL`. Default: `AUTO`
        :param pulumi.Input[_builtins.str] description: The description of the authorization server.
        :param pulumi.Input[_builtins.str] issuer: The complete URL for a Custom Authorization Server. This becomes the `iss` claim in an access token.
        :param pulumi.Input[_builtins.str] issuer_mode: *Early Access Property*. Allows you to use a custom issuer URL. It can be set to `CUSTOM_URL`, `ORG_URL`, or `DYNAMIC`. Default: `ORG_URL`
        :param pulumi.Input[_builtins.str] kid: The ID of the JSON Web Key used for signing tokens issued by the authorization server.
        :param pulumi.Input[_builtins.str] name: The name of the authorization server.
        :param pulumi.Input[_builtins.str] status: Default to `ACTIVE`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServerState.__new__(_ServerState)

        __props__.__dict__["audiences"] = audiences
        __props__.__dict__["credentials_last_rotated"] = credentials_last_rotated
        __props__.__dict__["credentials_next_rotation"] = credentials_next_rotation
        __props__.__dict__["credentials_rotation_mode"] = credentials_rotation_mode
        __props__.__dict__["description"] = description
        __props__.__dict__["issuer"] = issuer
        __props__.__dict__["issuer_mode"] = issuer_mode
        __props__.__dict__["kid"] = kid
        __props__.__dict__["name"] = name
        __props__.__dict__["status"] = status
        return Server(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def audiences(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The recipients that the tokens are intended for. This becomes the `aud` claim in an access token. Currently Okta only supports a single value here.
        """
        return pulumi.get(self, "audiences")

    @_builtins.property
    @pulumi.getter(name="credentialsLastRotated")
    def credentials_last_rotated(self) -> pulumi.Output[_builtins.str]:
        """
        The timestamp when the authorization server started to use the `kid` for signing tokens.
        """
        return pulumi.get(self, "credentials_last_rotated")

    @_builtins.property
    @pulumi.getter(name="credentialsNextRotation")
    def credentials_next_rotation(self) -> pulumi.Output[_builtins.str]:
        """
        The timestamp when the authorization server changes the key for signing tokens. Only returned when `credentials_rotation_mode` is `AUTO`.
        """
        return pulumi.get(self, "credentials_next_rotation")

    @_builtins.property
    @pulumi.getter(name="credentialsRotationMode")
    def credentials_rotation_mode(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The key rotation mode for the authorization server. Can be `AUTO` or `MANUAL`. Default: `AUTO`
        """
        return pulumi.get(self, "credentials_rotation_mode")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the authorization server.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def issuer(self) -> pulumi.Output[_builtins.str]:
        """
        The complete URL for a Custom Authorization Server. This becomes the `iss` claim in an access token.
        """
        return pulumi.get(self, "issuer")

    @_builtins.property
    @pulumi.getter(name="issuerMode")
    def issuer_mode(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        *Early Access Property*. Allows you to use a custom issuer URL. It can be set to `CUSTOM_URL`, `ORG_URL`, or `DYNAMIC`. Default: `ORG_URL`
        """
        return pulumi.get(self, "issuer_mode")

    @_builtins.property
    @pulumi.getter
    def kid(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the JSON Web Key used for signing tokens issued by the authorization server.
        """
        return pulumi.get(self, "kid")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the authorization server.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Default to `ACTIVE`
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetRequestSettingOrganizationResult',
    'AwaitableGetRequestSettingOrganizationResult',
    'get_request_setting_organization',
    'get_request_setting_organization_output',
]

@pulumi.output_type
class GetRequestSettingOrganizationResult:
    """
    A collection of values returned by getRequestSettingOrganization.
    """
    def __init__(__self__, id=None, long_time_past_provisioned=None, provisioning_status=None, request_experiences=None, subprocessors_acknowledged=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if long_time_past_provisioned and not isinstance(long_time_past_provisioned, bool):
            raise TypeError("Expected argument 'long_time_past_provisioned' to be a bool")
        pulumi.set(__self__, "long_time_past_provisioned", long_time_past_provisioned)
        if provisioning_status and not isinstance(provisioning_status, str):
            raise TypeError("Expected argument 'provisioning_status' to be a str")
        pulumi.set(__self__, "provisioning_status", provisioning_status)
        if request_experiences and not isinstance(request_experiences, list):
            raise TypeError("Expected argument 'request_experiences' to be a list")
        pulumi.set(__self__, "request_experiences", request_experiences)
        if subprocessors_acknowledged and not isinstance(subprocessors_acknowledged, bool):
            raise TypeError("Expected argument 'subprocessors_acknowledged' to be a bool")
        pulumi.set(__self__, "subprocessors_acknowledged", subprocessors_acknowledged)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="longTimePastProvisioned")
    def long_time_past_provisioned(self) -> _builtins.bool:
        return pulumi.get(self, "long_time_past_provisioned")

    @_builtins.property
    @pulumi.getter(name="provisioningStatus")
    def provisioning_status(self) -> _builtins.str:
        return pulumi.get(self, "provisioning_status")

    @_builtins.property
    @pulumi.getter(name="requestExperiences")
    def request_experiences(self) -> Optional[Sequence['outputs.GetRequestSettingOrganizationRequestExperienceResult']]:
        return pulumi.get(self, "request_experiences")

    @_builtins.property
    @pulumi.getter(name="subprocessorsAcknowledged")
    def subprocessors_acknowledged(self) -> _builtins.bool:
        return pulumi.get(self, "subprocessors_acknowledged")


class AwaitableGetRequestSettingOrganizationResult(GetRequestSettingOrganizationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRequestSettingOrganizationResult(
            id=self.id,
            long_time_past_provisioned=self.long_time_past_provisioned,
            provisioning_status=self.provisioning_status,
            request_experiences=self.request_experiences,
            subprocessors_acknowledged=self.subprocessors_acknowledged)


def get_request_setting_organization(request_experiences: Optional[Sequence[Union['GetRequestSettingOrganizationRequestExperienceArgs', 'GetRequestSettingOrganizationRequestExperienceArgsDict']]] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRequestSettingOrganizationResult:
    """
    Retrieves the request settings for the org.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_request_setting_organization()
    ```
    """
    __args__ = dict()
    __args__['requestExperiences'] = request_experiences
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getRequestSettingOrganization:getRequestSettingOrganization', __args__, opts=opts, typ=GetRequestSettingOrganizationResult).value

    return AwaitableGetRequestSettingOrganizationResult(
        id=pulumi.get(__ret__, 'id'),
        long_time_past_provisioned=pulumi.get(__ret__, 'long_time_past_provisioned'),
        provisioning_status=pulumi.get(__ret__, 'provisioning_status'),
        request_experiences=pulumi.get(__ret__, 'request_experiences'),
        subprocessors_acknowledged=pulumi.get(__ret__, 'subprocessors_acknowledged'))
def get_request_setting_organization_output(request_experiences: Optional[pulumi.Input[Optional[Sequence[Union['GetRequestSettingOrganizationRequestExperienceArgs', 'GetRequestSettingOrganizationRequestExperienceArgsDict']]]]] = None,
                                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRequestSettingOrganizationResult]:
    """
    Retrieves the request settings for the org.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_request_setting_organization()
    ```
    """
    __args__ = dict()
    __args__['requestExperiences'] = request_experiences
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getRequestSettingOrganization:getRequestSettingOrganization', __args__, opts=opts, typ=GetRequestSettingOrganizationResult)
    return __ret__.apply(lambda __response__: GetRequestSettingOrganizationResult(
        id=pulumi.get(__response__, 'id'),
        long_time_past_provisioned=pulumi.get(__response__, 'long_time_past_provisioned'),
        provisioning_status=pulumi.get(__response__, 'provisioning_status'),
        request_experiences=pulumi.get(__response__, 'request_experiences'),
        subprocessors_acknowledged=pulumi.get(__response__, 'subprocessors_acknowledged')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetServerResult',
    'AwaitableGetServerResult',
    'get_server',
    'get_server_output',
]

@pulumi.output_type
class GetServerResult:
    """
    A collection of values returned by getServer.
    """
    def __init__(__self__, audiences=None, credentials_last_rotated=None, credentials_next_rotation=None, credentials_rotation_mode=None, description=None, id=None, issuer=None, issuer_mode=None, kid=None, name=None, status=None):
        if audiences and not isinstance(audiences, list):
            raise TypeError("Expected argument 'audiences' to be a list")
        pulumi.set(__self__, "audiences", audiences)
        if credentials_last_rotated and not isinstance(credentials_last_rotated, str):
            raise TypeError("Expected argument 'credentials_last_rotated' to be a str")
        pulumi.set(__self__, "credentials_last_rotated", credentials_last_rotated)
        if credentials_next_rotation and not isinstance(credentials_next_rotation, str):
            raise TypeError("Expected argument 'credentials_next_rotation' to be a str")
        pulumi.set(__self__, "credentials_next_rotation", credentials_next_rotation)
        if credentials_rotation_mode and not isinstance(credentials_rotation_mode, str):
            raise TypeError("Expected argument 'credentials_rotation_mode' to be a str")
        pulumi.set(__self__, "credentials_rotation_mode", credentials_rotation_mode)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if issuer and not isinstance(issuer, str):
            raise TypeError("Expected argument 'issuer' to be a str")
        pulumi.set(__self__, "issuer", issuer)
        if issuer_mode and not isinstance(issuer_mode, str):
            raise TypeError("Expected argument 'issuer_mode' to be a str")
        pulumi.set(__self__, "issuer_mode", issuer_mode)
        if kid and not isinstance(kid, str):
            raise TypeError("Expected argument 'kid' to be a str")
        pulumi.set(__self__, "kid", kid)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def audiences(self) -> Sequence[_builtins.str]:
        """
        Description of Authorization server.
        """
        return pulumi.get(self, "audiences")

    @_builtins.property
    @pulumi.getter(name="credentialsLastRotated")
    def credentials_last_rotated(self) -> _builtins.str:
        """
        Last time credentials were rotated.
        """
        return pulumi.get(self, "credentials_last_rotated")

    @_builtins.property
    @pulumi.getter(name="credentialsNextRotation")
    def credentials_next_rotation(self) -> _builtins.str:
        """
        Next time credentials will be rotated
        """
        return pulumi.get(self, "credentials_next_rotation")

    @_builtins.property
    @pulumi.getter(name="credentialsRotationMode")
    def credentials_rotation_mode(self) -> _builtins.str:
        """
        Mode of credential rotation, auto or manual.
        """
        return pulumi.get(self, "credentials_rotation_mode")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of Authorization server.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def issuer(self) -> _builtins.str:
        """
        The complete URL of the authorization server. This becomes the `iss` claim in an access token.
        """
        return pulumi.get(self, "issuer")

    @_builtins.property
    @pulumi.getter(name="issuerMode")
    def issuer_mode(self) -> _builtins.str:
        """
        Can be set to `CUSTOM_URL` or `ORG_URL`
        """
        return pulumi.get(self, "issuer_mode")

    @_builtins.property
    @pulumi.getter
    def kid(self) -> _builtins.str:
        """
        Auth server key id.
        """
        return pulumi.get(self, "kid")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the auth server to retrieve.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The activation status of the authorization server.
        """
        return pulumi.get(self, "status")


class AwaitableGetServerResult(GetServerResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServerResult(
            audiences=self.audiences,
            credentials_last_rotated=self.credentials_last_rotated,
            credentials_next_rotation=self.credentials_next_rotation,
            credentials_rotation_mode=self.credentials_rotation_mode,
            description=self.description,
            id=self.id,
            issuer=self.issuer,
            issuer_mode=self.issuer_mode,
            kid=self.kid,
            name=self.name,
            status=self.status)


def get_server(name: Optional[_builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServerResult:
    """
    Get an auth server from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.auth.get_server(name="Example Auth")
    ```


    :param _builtins.str name: The name of the auth server to retrieve.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:auth/getServer:getServer', __args__, opts=opts, typ=GetServerResult).value

    return AwaitableGetServerResult(
        audiences=pulumi.get(__ret__, 'audiences'),
        credentials_last_rotated=pulumi.get(__ret__, 'credentials_last_rotated'),
        credentials_next_rotation=pulumi.get(__ret__, 'credentials_next_rotation'),
        credentials_rotation_mode=pulumi.get(__ret__, 'credentials_rotation_mode'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        issuer=pulumi.get(__ret__, 'issuer'),
        issuer_mode=pulumi.get(__ret__, 'issuer_mode'),
        kid=pulumi.get(__ret__, 'kid'),
        name=pulumi.get(__ret__, 'name'),
        status=pulumi.get(__ret__, 'status'))
def get_server_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetServerResult]:
    """
    Get an auth server from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.auth.get_server(name="Example Auth")
    ```


    :param _builtins.str name: The name of the auth server to retrieve.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:auth/getServer:getServer', __args__, opts=opts, typ=GetServerResult)
    return __ret__.apply(lambda __response__: GetServerResult(
        audiences=pulumi.get(__response__, 'audiences'),
        credentials_last_rotated=pulumi.get(__response__, 'credentials_last_rotated'),
        credentials_next_rotation=pulumi.get(__response__, 'credentials_next_rotation'),
        credentials_rotation_mode=pulumi.get(__response__, 'credentials_rotation_mode'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        issuer=pulumi.get(__response__, 'issuer'),
        issuer_mode=pulumi.get(__response__, 'issuer_mode'),
        kid=pulumi.get(__response__, 'kid'),
        name=pulumi.get(__response__, 'name'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EndUserMyRequestsArgs', 'EndUserMyRequests']

@pulumi.input_type
class EndUserMyRequestsArgs:
    def __init__(__self__, *,
                 entry_id: pulumi.Input[_builtins.str],
                 requester_field_values: Optional[pulumi.Input[Sequence[pulumi.Input['EndUserMyRequestsRequesterFieldValueArgs']]]] = None):
        """
        The set of arguments for constructing a EndUserMyRequests resource.
        :param pulumi.Input[_builtins.str] entry_id: The ID of the catalog entry for which the request is being made.
        :param pulumi.Input[Sequence[pulumi.Input['EndUserMyRequestsRequesterFieldValueArgs']]] requester_field_values: The requester input fields required by the approval system. Note: The fields required are determined by the approval system.
        """
        pulumi.set(__self__, "entry_id", entry_id)
        if requester_field_values is not None:
            pulumi.set(__self__, "requester_field_values", requester_field_values)

    @_builtins.property
    @pulumi.getter(name="entryId")
    def entry_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the catalog entry for which the request is being made.
        """
        return pulumi.get(self, "entry_id")

    @entry_id.setter
    def entry_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "entry_id", value)

    @_builtins.property
    @pulumi.getter(name="requesterFieldValues")
    def requester_field_values(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EndUserMyRequestsRequesterFieldValueArgs']]]]:
        """
        The requester input fields required by the approval system. Note: The fields required are determined by the approval system.
        """
        return pulumi.get(self, "requester_field_values")

    @requester_field_values.setter
    def requester_field_values(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EndUserMyRequestsRequesterFieldValueArgs']]]]):
        pulumi.set(self, "requester_field_values", value)


@pulumi.input_type
class _EndUserMyRequestsState:
    def __init__(__self__, *,
                 entry_id: Optional[pulumi.Input[_builtins.str]] = None,
                 requester_field_values: Optional[pulumi.Input[Sequence[pulumi.Input['EndUserMyRequestsRequesterFieldValueArgs']]]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering EndUserMyRequests resources.
        :param pulumi.Input[_builtins.str] entry_id: The ID of the catalog entry for which the request is being made.
        :param pulumi.Input[Sequence[pulumi.Input['EndUserMyRequestsRequesterFieldValueArgs']]] requester_field_values: The requester input fields required by the approval system. Note: The fields required are determined by the approval system.
        :param pulumi.Input[_builtins.str] status: The status of the request. Possible values include: `APPROVED`, `CANCELED`, `DENIED`, `EXPIRED`, `PENDING`, `REJECTED`, `SUBMITTED`
        """
        if entry_id is not None:
            pulumi.set(__self__, "entry_id", entry_id)
        if requester_field_values is not None:
            pulumi.set(__self__, "requester_field_values", requester_field_values)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="entryId")
    def entry_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the catalog entry for which the request is being made.
        """
        return pulumi.get(self, "entry_id")

    @entry_id.setter
    def entry_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "entry_id", value)

    @_builtins.property
    @pulumi.getter(name="requesterFieldValues")
    def requester_field_values(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EndUserMyRequestsRequesterFieldValueArgs']]]]:
        """
        The requester input fields required by the approval system. Note: The fields required are determined by the approval system.
        """
        return pulumi.get(self, "requester_field_values")

    @requester_field_values.setter
    def requester_field_values(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EndUserMyRequestsRequesterFieldValueArgs']]]]):
        pulumi.set(self, "requester_field_values", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the request. Possible values include: `APPROVED`, `CANCELED`, `DENIED`, `EXPIRED`, `PENDING`, `REJECTED`, `SUBMITTED`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("okta:index/endUserMyRequests:EndUserMyRequests")
class EndUserMyRequests(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 entry_id: Optional[pulumi.Input[_builtins.str]] = None,
                 requester_field_values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndUserMyRequestsRequesterFieldValueArgs', 'EndUserMyRequestsRequesterFieldValueArgsDict']]]]] = None,
                 __props__=None):
        """
        ## Import

        ```sh
        $ pulumi import okta:index/endUserMyRequests:EndUserMyRequests example <request_id/entry_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] entry_id: The ID of the catalog entry for which the request is being made.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EndUserMyRequestsRequesterFieldValueArgs', 'EndUserMyRequestsRequesterFieldValueArgsDict']]]] requester_field_values: The requester input fields required by the approval system. Note: The fields required are determined by the approval system.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EndUserMyRequestsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        ```sh
        $ pulumi import okta:index/endUserMyRequests:EndUserMyRequests example <request_id/entry_id>
        ```

        :param str resource_name: The name of the resource.
        :param EndUserMyRequestsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EndUserMyRequestsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 entry_id: Optional[pulumi.Input[_builtins.str]] = None,
                 requester_field_values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndUserMyRequestsRequesterFieldValueArgs', 'EndUserMyRequestsRequesterFieldValueArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EndUserMyRequestsArgs.__new__(EndUserMyRequestsArgs)

            if entry_id is None and not opts.urn:
                raise TypeError("Missing required property 'entry_id'")
            __props__.__dict__["entry_id"] = entry_id
            __props__.__dict__["requester_field_values"] = requester_field_values
            __props__.__dict__["status"] = None
        super(EndUserMyRequests, __self__).__init__(
            'okta:index/endUserMyRequests:EndUserMyRequests',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            entry_id: Optional[pulumi.Input[_builtins.str]] = None,
            requester_field_values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndUserMyRequestsRequesterFieldValueArgs', 'EndUserMyRequestsRequesterFieldValueArgsDict']]]]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None) -> 'EndUserMyRequests':
        """
        Get an existing EndUserMyRequests resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] entry_id: The ID of the catalog entry for which the request is being made.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EndUserMyRequestsRequesterFieldValueArgs', 'EndUserMyRequestsRequesterFieldValueArgsDict']]]] requester_field_values: The requester input fields required by the approval system. Note: The fields required are determined by the approval system.
        :param pulumi.Input[_builtins.str] status: The status of the request. Possible values include: `APPROVED`, `CANCELED`, `DENIED`, `EXPIRED`, `PENDING`, `REJECTED`, `SUBMITTED`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EndUserMyRequestsState.__new__(_EndUserMyRequestsState)

        __props__.__dict__["entry_id"] = entry_id
        __props__.__dict__["requester_field_values"] = requester_field_values
        __props__.__dict__["status"] = status
        return EndUserMyRequests(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="entryId")
    def entry_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the catalog entry for which the request is being made.
        """
        return pulumi.get(self, "entry_id")

    @_builtins.property
    @pulumi.getter(name="requesterFieldValues")
    def requester_field_values(self) -> pulumi.Output[Optional[Sequence['outputs.EndUserMyRequestsRequesterFieldValue']]]:
        """
        The requester input fields required by the approval system. Note: The fields required are determined by the approval system.
        """
        return pulumi.get(self, "requester_field_values")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the request. Possible values include: `APPROVED`, `CANCELED`, `DENIED`, `EXPIRED`, `PENDING`, `REJECTED`, `SUBMITTED`
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['RateLimitAdminNotificationSettingsArgs', 'RateLimitAdminNotificationSettings']

@pulumi.input_type
class RateLimitAdminNotificationSettingsArgs:
    def __init__(__self__, *,
                 notifications_enabled: pulumi.Input[_builtins.bool]):
        """
        The set of arguments for constructing a RateLimitAdminNotificationSettings resource.
        :param pulumi.Input[_builtins.bool] notifications_enabled: Enables or disables admin notifications for rate limiting events.
        """
        pulumi.set(__self__, "notifications_enabled", notifications_enabled)

    @_builtins.property
    @pulumi.getter(name="notificationsEnabled")
    def notifications_enabled(self) -> pulumi.Input[_builtins.bool]:
        """
        Enables or disables admin notifications for rate limiting events.
        """
        return pulumi.get(self, "notifications_enabled")

    @notifications_enabled.setter
    def notifications_enabled(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "notifications_enabled", value)


@pulumi.input_type
class _RateLimitAdminNotificationSettingsState:
    def __init__(__self__, *,
                 notifications_enabled: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering RateLimitAdminNotificationSettings resources.
        :param pulumi.Input[_builtins.bool] notifications_enabled: Enables or disables admin notifications for rate limiting events.
        """
        if notifications_enabled is not None:
            pulumi.set(__self__, "notifications_enabled", notifications_enabled)

    @_builtins.property
    @pulumi.getter(name="notificationsEnabled")
    def notifications_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enables or disables admin notifications for rate limiting events.
        """
        return pulumi.get(self, "notifications_enabled")

    @notifications_enabled.setter
    def notifications_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "notifications_enabled", value)


@pulumi.type_token("okta:index/rateLimitAdminNotificationSettings:RateLimitAdminNotificationSettings")
class RateLimitAdminNotificationSettings(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 notifications_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Manages principal rate limits.
        Principal Rate Limits provides operations to manage Principal Rate Limits for your organization.
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.RateLimitAdminNotificationSettings("example", notifications_enabled=True)
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/rateLimitAdminNotificationSettings:RateLimitAdminNotificationSettings example .
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] notifications_enabled: Enables or disables admin notifications for rate limiting events.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RateLimitAdminNotificationSettingsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages principal rate limits.
        Principal Rate Limits provides operations to manage Principal Rate Limits for your organization.
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.RateLimitAdminNotificationSettings("example", notifications_enabled=True)
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/rateLimitAdminNotificationSettings:RateLimitAdminNotificationSettings example .
        ```

        :param str resource_name: The name of the resource.
        :param RateLimitAdminNotificationSettingsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RateLimitAdminNotificationSettingsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 notifications_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RateLimitAdminNotificationSettingsArgs.__new__(RateLimitAdminNotificationSettingsArgs)

            if notifications_enabled is None and not opts.urn:
                raise TypeError("Missing required property 'notifications_enabled'")
            __props__.__dict__["notifications_enabled"] = notifications_enabled
        super(RateLimitAdminNotificationSettings, __self__).__init__(
            'okta:index/rateLimitAdminNotificationSettings:RateLimitAdminNotificationSettings',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            notifications_enabled: Optional[pulumi.Input[_builtins.bool]] = None) -> 'RateLimitAdminNotificationSettings':
        """
        Get an existing RateLimitAdminNotificationSettings resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] notifications_enabled: Enables or disables admin notifications for rate limiting events.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RateLimitAdminNotificationSettingsState.__new__(_RateLimitAdminNotificationSettingsState)

        __props__.__dict__["notifications_enabled"] = notifications_enabled
        return RateLimitAdminNotificationSettings(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="notificationsEnabled")
    def notifications_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enables or disables admin notifications for rate limiting events.
        """
        return pulumi.get(self, "notifications_enabled")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ConnectionArgs', 'Connection']

@pulumi.input_type
class ConnectionArgs:
    def __init__(__self__, *,
                 action: pulumi.Input[_builtins.str],
                 base_url: pulumi.Input[_builtins.str],
                 id_property: pulumi.Input[_builtins.str],
                 profile: Optional[pulumi.Input['ConnectionProfileArgs']] = None):
        """
        The set of arguments for constructing a Connection resource.
        :param pulumi.Input[_builtins.str] action: The action to perform on the connection. Valid values are `activate` or `deactivate`.
        :param pulumi.Input[_builtins.str] base_url: The base URL for the provisioning connection.
        :param pulumi.Input[_builtins.str] id_property: The application ID.
        :param pulumi.Input['ConnectionProfileArgs'] profile: Profile configuration for the app connection.
        """
        pulumi.set(__self__, "action", action)
        pulumi.set(__self__, "base_url", base_url)
        pulumi.set(__self__, "id_property", id_property)
        if profile is not None:
            pulumi.set(__self__, "profile", profile)

    @_builtins.property
    @pulumi.getter
    def action(self) -> pulumi.Input[_builtins.str]:
        """
        The action to perform on the connection. Valid values are `activate` or `deactivate`.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "action", value)

    @_builtins.property
    @pulumi.getter(name="baseUrl")
    def base_url(self) -> pulumi.Input[_builtins.str]:
        """
        The base URL for the provisioning connection.
        """
        return pulumi.get(self, "base_url")

    @base_url.setter
    def base_url(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "base_url", value)

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> pulumi.Input[_builtins.str]:
        """
        The application ID.
        """
        return pulumi.get(self, "id_property")

    @id_property.setter
    def id_property(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "id_property", value)

    @_builtins.property
    @pulumi.getter
    def profile(self) -> Optional[pulumi.Input['ConnectionProfileArgs']]:
        """
        Profile configuration for the app connection.
        """
        return pulumi.get(self, "profile")

    @profile.setter
    def profile(self, value: Optional[pulumi.Input['ConnectionProfileArgs']]):
        pulumi.set(self, "profile", value)


@pulumi.input_type
class _ConnectionState:
    def __init__(__self__, *,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 base_url: Optional[pulumi.Input[_builtins.str]] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 profile: Optional[pulumi.Input['ConnectionProfileArgs']] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Connection resources.
        :param pulumi.Input[_builtins.str] action: The action to perform on the connection. Valid values are `activate` or `deactivate`.
        :param pulumi.Input[_builtins.str] base_url: The base URL for the provisioning connection.
        :param pulumi.Input[_builtins.str] id_property: The application ID.
        :param pulumi.Input['ConnectionProfileArgs'] profile: Profile configuration for the app connection.
        :param pulumi.Input[_builtins.str] status: Provisioning connection status.
        """
        if action is not None:
            pulumi.set(__self__, "action", action)
        if base_url is not None:
            pulumi.set(__self__, "base_url", base_url)
        if id_property is not None:
            pulumi.set(__self__, "id_property", id_property)
        if profile is not None:
            pulumi.set(__self__, "profile", profile)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The action to perform on the connection. Valid values are `activate` or `deactivate`.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "action", value)

    @_builtins.property
    @pulumi.getter(name="baseUrl")
    def base_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The base URL for the provisioning connection.
        """
        return pulumi.get(self, "base_url")

    @base_url.setter
    def base_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "base_url", value)

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The application ID.
        """
        return pulumi.get(self, "id_property")

    @id_property.setter
    def id_property(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id_property", value)

    @_builtins.property
    @pulumi.getter
    def profile(self) -> Optional[pulumi.Input['ConnectionProfileArgs']]:
        """
        Profile configuration for the app connection.
        """
        return pulumi.get(self, "profile")

    @profile.setter
    def profile(self, value: Optional[pulumi.Input['ConnectionProfileArgs']]):
        pulumi.set(self, "profile", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Provisioning connection status.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("okta:app/connection:Connection")
class Connection(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 base_url: Optional[pulumi.Input[_builtins.str]] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 profile: Optional[pulumi.Input[Union['ConnectionProfileArgs', 'ConnectionProfileArgsDict']]] = None,
                 __props__=None):
        """
        Manages Okta App Connection configurations for provisioning. This resource allows you to configure and manage provisioning connections for applications, including authentication schemes and connection activation/deactivation.

        ## Example Usage

        ### TOKEN Authentication

        ```python
        import pulumi
        import pulumi_okta as okta

        token_example = okta.app.Connection("token_example",
            id_property="0oa1234567890abcdef",
            base_url="https://api.example.com/scim/v2",
            action="activate",
            profile={
                "auth_scheme": "TOKEN",
                "token": "your-bearer-token-here",
            })
        ```

        ### OAUTH2 Authentication

        ```python
        import pulumi
        import pulumi_okta as okta

        oauth2_example = okta.app.Connection("oauth2_example",
            id_property="0oa1234567890abcdef",
            action="activate",
            profile={
                "auth_scheme": "OAUTH2",
                "client_id": "oauth2-client-id",
                "settings": {
                    "admin_username": "admin@example.com",
                    "admin_password": "secure-password",
                },
                "signing": {
                    "rotation_mode": "MANUAL",
                },
            })
        ```

        ### Deactivated Connection

        ```python
        import pulumi
        import pulumi_okta as okta

        deactivated_example = okta.app.Connection("deactivated_example",
            id_property="0oa1234567890abcdef",
            base_url="https://api.example.com/scim/v2",
            action="deactivate",
            profile={
                "auth_scheme": "TOKEN",
                "token": "your-bearer-token-here",
            })
        ```

        ## Import

        App connections can be imported using the application ID:

        ```sh
        $ pulumi import okta:app/connection:Connection example <application_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] action: The action to perform on the connection. Valid values are `activate` or `deactivate`.
        :param pulumi.Input[_builtins.str] base_url: The base URL for the provisioning connection.
        :param pulumi.Input[_builtins.str] id_property: The application ID.
        :param pulumi.Input[Union['ConnectionProfileArgs', 'ConnectionProfileArgsDict']] profile: Profile configuration for the app connection.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConnectionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Okta App Connection configurations for provisioning. This resource allows you to configure and manage provisioning connections for applications, including authentication schemes and connection activation/deactivation.

        ## Example Usage

        ### TOKEN Authentication

        ```python
        import pulumi
        import pulumi_okta as okta

        token_example = okta.app.Connection("token_example",
            id_property="0oa1234567890abcdef",
            base_url="https://api.example.com/scim/v2",
            action="activate",
            profile={
                "auth_scheme": "TOKEN",
                "token": "your-bearer-token-here",
            })
        ```

        ### OAUTH2 Authentication

        ```python
        import pulumi
        import pulumi_okta as okta

        oauth2_example = okta.app.Connection("oauth2_example",
            id_property="0oa1234567890abcdef",
            action="activate",
            profile={
                "auth_scheme": "OAUTH2",
                "client_id": "oauth2-client-id",
                "settings": {
                    "admin_username": "admin@example.com",
                    "admin_password": "secure-password",
                },
                "signing": {
                    "rotation_mode": "MANUAL",
                },
            })
        ```

        ### Deactivated Connection

        ```python
        import pulumi
        import pulumi_okta as okta

        deactivated_example = okta.app.Connection("deactivated_example",
            id_property="0oa1234567890abcdef",
            base_url="https://api.example.com/scim/v2",
            action="deactivate",
            profile={
                "auth_scheme": "TOKEN",
                "token": "your-bearer-token-here",
            })
        ```

        ## Import

        App connections can be imported using the application ID:

        ```sh
        $ pulumi import okta:app/connection:Connection example <application_id>
        ```

        :param str resource_name: The name of the resource.
        :param ConnectionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConnectionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 base_url: Optional[pulumi.Input[_builtins.str]] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 profile: Optional[pulumi.Input[Union['ConnectionProfileArgs', 'ConnectionProfileArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConnectionArgs.__new__(ConnectionArgs)

            if action is None and not opts.urn:
                raise TypeError("Missing required property 'action'")
            __props__.__dict__["action"] = action
            if base_url is None and not opts.urn:
                raise TypeError("Missing required property 'base_url'")
            __props__.__dict__["base_url"] = base_url
            if id_property is None and not opts.urn:
                raise TypeError("Missing required property 'id_property'")
            __props__.__dict__["id_property"] = id_property
            __props__.__dict__["profile"] = profile
            __props__.__dict__["status"] = None
        super(Connection, __self__).__init__(
            'okta:app/connection:Connection',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action: Optional[pulumi.Input[_builtins.str]] = None,
            base_url: Optional[pulumi.Input[_builtins.str]] = None,
            id_property: Optional[pulumi.Input[_builtins.str]] = None,
            profile: Optional[pulumi.Input[Union['ConnectionProfileArgs', 'ConnectionProfileArgsDict']]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None) -> 'Connection':
        """
        Get an existing Connection resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] action: The action to perform on the connection. Valid values are `activate` or `deactivate`.
        :param pulumi.Input[_builtins.str] base_url: The base URL for the provisioning connection.
        :param pulumi.Input[_builtins.str] id_property: The application ID.
        :param pulumi.Input[Union['ConnectionProfileArgs', 'ConnectionProfileArgsDict']] profile: Profile configuration for the app connection.
        :param pulumi.Input[_builtins.str] status: Provisioning connection status.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConnectionState.__new__(_ConnectionState)

        __props__.__dict__["action"] = action
        __props__.__dict__["base_url"] = base_url
        __props__.__dict__["id_property"] = id_property
        __props__.__dict__["profile"] = profile
        __props__.__dict__["status"] = status
        return Connection(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def action(self) -> pulumi.Output[_builtins.str]:
        """
        The action to perform on the connection. Valid values are `activate` or `deactivate`.
        """
        return pulumi.get(self, "action")

    @_builtins.property
    @pulumi.getter(name="baseUrl")
    def base_url(self) -> pulumi.Output[_builtins.str]:
        """
        The base URL for the provisioning connection.
        """
        return pulumi.get(self, "base_url")

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> pulumi.Output[_builtins.str]:
        """
        The application ID.
        """
        return pulumi.get(self, "id_property")

    @_builtins.property
    @pulumi.getter
    def profile(self) -> pulumi.Output[Optional['outputs.ConnectionProfile']]:
        """
        Profile configuration for the app connection.
        """
        return pulumi.get(self, "profile")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        Provisioning connection status.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['DeviceArgs', 'Device']

@pulumi.input_type
class DeviceArgs:
    def __init__(__self__, *,
                 action: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Device resource.
        :param pulumi.Input[_builtins.str] action: The action of the device.
        """
        if action is not None:
            pulumi.set(__self__, "action", action)

    @_builtins.property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The action of the device.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "action", value)


@pulumi.input_type
class _DeviceState:
    def __init__(__self__, *,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Device resources.
        :param pulumi.Input[_builtins.str] action: The action of the device.
        :param pulumi.Input[_builtins.str] resource_type: The resource type of the device.
        :param pulumi.Input[_builtins.str] status: The status of the device.
        """
        if action is not None:
            pulumi.set(__self__, "action", action)
        if resource_type is not None:
            pulumi.set(__self__, "resource_type", resource_type)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The action of the device.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "action", value)

    @_builtins.property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The resource type of the device.
        """
        return pulumi.get(self, "resource_type")

    @resource_type.setter
    def resource_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_type", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the device.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("okta:index/device:Device")
class Device(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.Device("example", action="SUSPEND")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/device:Device example <device_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] action: The action of the device.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[DeviceArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.Device("example", action="SUSPEND")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/device:Device example <device_id>
        ```

        :param str resource_name: The name of the resource.
        :param DeviceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DeviceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DeviceArgs.__new__(DeviceArgs)

            __props__.__dict__["action"] = action
            __props__.__dict__["resource_type"] = None
            __props__.__dict__["status"] = None
        super(Device, __self__).__init__(
            'okta:index/device:Device',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action: Optional[pulumi.Input[_builtins.str]] = None,
            resource_type: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None) -> 'Device':
        """
        Get an existing Device resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] action: The action of the device.
        :param pulumi.Input[_builtins.str] resource_type: The resource type of the device.
        :param pulumi.Input[_builtins.str] status: The status of the device.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DeviceState.__new__(_DeviceState)

        __props__.__dict__["action"] = action
        __props__.__dict__["resource_type"] = resource_type
        __props__.__dict__["status"] = status
        return Device(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def action(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The action of the device.
        """
        return pulumi.get(self, "action")

    @_builtins.property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> pulumi.Output[_builtins.str]:
        """
        The resource type of the device.
        """
        return pulumi.get(self, "resource_type")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the device.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RoleArgs', 'Role']

@pulumi.input_type
class RoleArgs:
    def __init__(__self__, *,
                 group_id: pulumi.Input[_builtins.str],
                 role_type: pulumi.Input[_builtins.str],
                 disable_notifications: Optional[pulumi.Input[_builtins.bool]] = None,
                 resource_set_id: Optional[pulumi.Input[_builtins.str]] = None,
                 role_id: Optional[pulumi.Input[_builtins.str]] = None,
                 target_app_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 target_group_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a Role resource.
        :param pulumi.Input[_builtins.str] group_id: ID of group to attach admin roles to
        :param pulumi.Input[_builtins.str] role_type: Admin role assigned to the group. It can be any one of the following values:
               	"API_ADMIN",
               	"APP_ADMIN",
               	"CUSTOM",
               	"GROUP_MEMBERSHIP_ADMIN",
               	"HELP_DESK_ADMIN",
               	"MOBILE_ADMIN",
               	"ORG_ADMIN",
               	"READ_ONLY_ADMIN",
               	"REPORT_ADMIN",
               	"SUPER_ADMIN",
               	"USER_ADMIN"
               	. See [API Docs](https://developer.okta.com/docs/api/openapi/okta-management/guides/roles/#standard-roles).
               	- "USER_ADMIN" is the Group Administrator.
        :param pulumi.Input[_builtins.bool] disable_notifications: When this setting is enabled, the admins won't receive any of the default Okta administrator emails. These admins also won't have access to contact Okta Support and open support cases on behalf of your org.
        :param pulumi.Input[_builtins.str] resource_set_id: Resource Set ID. Required for role_type = `CUSTOM`
        :param pulumi.Input[_builtins.str] role_id: Role ID. Required for role_type = `CUSTOM`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] target_app_lists: A list of app names (name represents set of app instances, like 'salesforce' or 'facebook'), or a combination of app name and app instance ID (like 'facebook.0oapsqQ6dv19pqyEo0g3') you would like as the targets of the admin role. - Only supported when used with the role type `APP_ADMIN`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] target_group_lists: A list of group IDs you would like as the targets of the admin role. - Only supported when used with the role types: `GROUP_MEMBERSHIP_ADMIN`, `HELP_DESK_ADMIN`, or `USER_ADMIN`.
        """
        pulumi.set(__self__, "group_id", group_id)
        pulumi.set(__self__, "role_type", role_type)
        if disable_notifications is not None:
            pulumi.set(__self__, "disable_notifications", disable_notifications)
        if resource_set_id is not None:
            pulumi.set(__self__, "resource_set_id", resource_set_id)
        if role_id is not None:
            pulumi.set(__self__, "role_id", role_id)
        if target_app_lists is not None:
            pulumi.set(__self__, "target_app_lists", target_app_lists)
        if target_group_lists is not None:
            pulumi.set(__self__, "target_group_lists", target_group_lists)

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of group to attach admin roles to
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "group_id", value)

    @_builtins.property
    @pulumi.getter(name="roleType")
    def role_type(self) -> pulumi.Input[_builtins.str]:
        """
        Admin role assigned to the group. It can be any one of the following values:
        	"API_ADMIN",
        	"APP_ADMIN",
        	"CUSTOM",
        	"GROUP_MEMBERSHIP_ADMIN",
        	"HELP_DESK_ADMIN",
        	"MOBILE_ADMIN",
        	"ORG_ADMIN",
        	"READ_ONLY_ADMIN",
        	"REPORT_ADMIN",
        	"SUPER_ADMIN",
        	"USER_ADMIN"
        	. See [API Docs](https://developer.okta.com/docs/api/openapi/okta-management/guides/roles/#standard-roles).
        	- "USER_ADMIN" is the Group Administrator.
        """
        return pulumi.get(self, "role_type")

    @role_type.setter
    def role_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "role_type", value)

    @_builtins.property
    @pulumi.getter(name="disableNotifications")
    def disable_notifications(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When this setting is enabled, the admins won't receive any of the default Okta administrator emails. These admins also won't have access to contact Okta Support and open support cases on behalf of your org.
        """
        return pulumi.get(self, "disable_notifications")

    @disable_notifications.setter
    def disable_notifications(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_notifications", value)

    @_builtins.property
    @pulumi.getter(name="resourceSetId")
    def resource_set_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Resource Set ID. Required for role_type = `CUSTOM`
        """
        return pulumi.get(self, "resource_set_id")

    @resource_set_id.setter
    def resource_set_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_set_id", value)

    @_builtins.property
    @pulumi.getter(name="roleId")
    def role_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Role ID. Required for role_type = `CUSTOM`
        """
        return pulumi.get(self, "role_id")

    @role_id.setter
    def role_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "role_id", value)

    @_builtins.property
    @pulumi.getter(name="targetAppLists")
    def target_app_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of app names (name represents set of app instances, like 'salesforce' or 'facebook'), or a combination of app name and app instance ID (like 'facebook.0oapsqQ6dv19pqyEo0g3') you would like as the targets of the admin role. - Only supported when used with the role type `APP_ADMIN`.
        """
        return pulumi.get(self, "target_app_lists")

    @target_app_lists.setter
    def target_app_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "target_app_lists", value)

    @_builtins.property
    @pulumi.getter(name="targetGroupLists")
    def target_group_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of group IDs you would like as the targets of the admin role. - Only supported when used with the role types: `GROUP_MEMBERSHIP_ADMIN`, `HELP_DESK_ADMIN`, or `USER_ADMIN`.
        """
        return pulumi.get(self, "target_group_lists")

    @target_group_lists.setter
    def target_group_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "target_group_lists", value)


@pulumi.input_type
class _RoleState:
    def __init__(__self__, *,
                 disable_notifications: Optional[pulumi.Input[_builtins.bool]] = None,
                 group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_set_id: Optional[pulumi.Input[_builtins.str]] = None,
                 role_id: Optional[pulumi.Input[_builtins.str]] = None,
                 role_type: Optional[pulumi.Input[_builtins.str]] = None,
                 target_app_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 target_group_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Role resources.
        :param pulumi.Input[_builtins.bool] disable_notifications: When this setting is enabled, the admins won't receive any of the default Okta administrator emails. These admins also won't have access to contact Okta Support and open support cases on behalf of your org.
        :param pulumi.Input[_builtins.str] group_id: ID of group to attach admin roles to
        :param pulumi.Input[_builtins.str] resource_set_id: Resource Set ID. Required for role_type = `CUSTOM`
        :param pulumi.Input[_builtins.str] role_id: Role ID. Required for role_type = `CUSTOM`
        :param pulumi.Input[_builtins.str] role_type: Admin role assigned to the group. It can be any one of the following values:
               	"API_ADMIN",
               	"APP_ADMIN",
               	"CUSTOM",
               	"GROUP_MEMBERSHIP_ADMIN",
               	"HELP_DESK_ADMIN",
               	"MOBILE_ADMIN",
               	"ORG_ADMIN",
               	"READ_ONLY_ADMIN",
               	"REPORT_ADMIN",
               	"SUPER_ADMIN",
               	"USER_ADMIN"
               	. See [API Docs](https://developer.okta.com/docs/api/openapi/okta-management/guides/roles/#standard-roles).
               	- "USER_ADMIN" is the Group Administrator.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] target_app_lists: A list of app names (name represents set of app instances, like 'salesforce' or 'facebook'), or a combination of app name and app instance ID (like 'facebook.0oapsqQ6dv19pqyEo0g3') you would like as the targets of the admin role. - Only supported when used with the role type `APP_ADMIN`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] target_group_lists: A list of group IDs you would like as the targets of the admin role. - Only supported when used with the role types: `GROUP_MEMBERSHIP_ADMIN`, `HELP_DESK_ADMIN`, or `USER_ADMIN`.
        """
        if disable_notifications is not None:
            pulumi.set(__self__, "disable_notifications", disable_notifications)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if resource_set_id is not None:
            pulumi.set(__self__, "resource_set_id", resource_set_id)
        if role_id is not None:
            pulumi.set(__self__, "role_id", role_id)
        if role_type is not None:
            pulumi.set(__self__, "role_type", role_type)
        if target_app_lists is not None:
            pulumi.set(__self__, "target_app_lists", target_app_lists)
        if target_group_lists is not None:
            pulumi.set(__self__, "target_group_lists", target_group_lists)

    @_builtins.property
    @pulumi.getter(name="disableNotifications")
    def disable_notifications(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When this setting is enabled, the admins won't receive any of the default Okta administrator emails. These admins also won't have access to contact Okta Support and open support cases on behalf of your org.
        """
        return pulumi.get(self, "disable_notifications")

    @disable_notifications.setter
    def disable_notifications(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_notifications", value)

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of group to attach admin roles to
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "group_id", value)

    @_builtins.property
    @pulumi.getter(name="resourceSetId")
    def resource_set_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Resource Set ID. Required for role_type = `CUSTOM`
        """
        return pulumi.get(self, "resource_set_id")

    @resource_set_id.setter
    def resource_set_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_set_id", value)

    @_builtins.property
    @pulumi.getter(name="roleId")
    def role_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Role ID. Required for role_type = `CUSTOM`
        """
        return pulumi.get(self, "role_id")

    @role_id.setter
    def role_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "role_id", value)

    @_builtins.property
    @pulumi.getter(name="roleType")
    def role_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Admin role assigned to the group. It can be any one of the following values:
        	"API_ADMIN",
        	"APP_ADMIN",
        	"CUSTOM",
        	"GROUP_MEMBERSHIP_ADMIN",
        	"HELP_DESK_ADMIN",
        	"MOBILE_ADMIN",
        	"ORG_ADMIN",
        	"READ_ONLY_ADMIN",
        	"REPORT_ADMIN",
        	"SUPER_ADMIN",
        	"USER_ADMIN"
        	. See [API Docs](https://developer.okta.com/docs/api/openapi/okta-management/guides/roles/#standard-roles).
        	- "USER_ADMIN" is the Group Administrator.
        """
        return pulumi.get(self, "role_type")

    @role_type.setter
    def role_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "role_type", value)

    @_builtins.property
    @pulumi.getter(name="targetAppLists")
    def target_app_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of app names (name represents set of app instances, like 'salesforce' or 'facebook'), or a combination of app name and app instance ID (like 'facebook.0oapsqQ6dv19pqyEo0g3') you would like as the targets of the admin role. - Only supported when used with the role type `APP_ADMIN`.
        """
        return pulumi.get(self, "target_app_lists")

    @target_app_lists.setter
    def target_app_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "target_app_lists", value)

    @_builtins.property
    @pulumi.getter(name="targetGroupLists")
    def target_group_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of group IDs you would like as the targets of the admin role. - Only supported when used with the role types: `GROUP_MEMBERSHIP_ADMIN`, `HELP_DESK_ADMIN`, or `USER_ADMIN`.
        """
        return pulumi.get(self, "target_group_lists")

    @target_group_lists.setter
    def target_group_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "target_group_lists", value)


@pulumi.type_token("okta:group/role:Role")
class Role(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disable_notifications: Optional[pulumi.Input[_builtins.bool]] = None,
                 group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_set_id: Optional[pulumi.Input[_builtins.str]] = None,
                 role_id: Optional[pulumi.Input[_builtins.str]] = None,
                 role_type: Optional[pulumi.Input[_builtins.str]] = None,
                 target_app_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 target_group_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Assigns Admin roles to Okta Groups. This resource allows you to assign Okta administrator roles to Okta Groups. This resource provides a one-to-one interface between the Okta group and the admin role.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta
        import pulumi_std as std

        example = okta.group.Role("example",
            group_id="<group id>",
            role_type="READ_ONLY_ADMIN")
        # Example for CUSTOM role
        test = okta.group.Group("test",
            name="testAcc_replace_with_uuid",
            description="testing")
        test_resource_set = okta.ResourceSet("test",
            label="test",
            description="testing, testing",
            resources=[std.index.format(input="%s/api/v1/users",
                args=["https://tien-oie-2023-26-26.oktapreview.com"])["result"]])
        test_admin_role_custom = okta.AdminRoleCustom("test",
            label="testt",
            description="testing, testing",
            permissions=[
                "okta.apps.assignment.manage",
                "okta.users.manage",
                "okta.apps.manage",
            ])
        test_role = okta.group.Role("test",
            group_id=test.id,
            role_id=test_admin_role_custom.id,
            resource_set_id=test_resource_set.id,
            role_type="CUSTOM")
        ```

        ## Import

        ```sh
        $ pulumi import okta:group/role:Role example <group_id>/<role_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] disable_notifications: When this setting is enabled, the admins won't receive any of the default Okta administrator emails. These admins also won't have access to contact Okta Support and open support cases on behalf of your org.
        :param pulumi.Input[_builtins.str] group_id: ID of group to attach admin roles to
        :param pulumi.Input[_builtins.str] resource_set_id: Resource Set ID. Required for role_type = `CUSTOM`
        :param pulumi.Input[_builtins.str] role_id: Role ID. Required for role_type = `CUSTOM`
        :param pulumi.Input[_builtins.str] role_type: Admin role assigned to the group. It can be any one of the following values:
               	"API_ADMIN",
               	"APP_ADMIN",
               	"CUSTOM",
               	"GROUP_MEMBERSHIP_ADMIN",
               	"HELP_DESK_ADMIN",
               	"MOBILE_ADMIN",
               	"ORG_ADMIN",
               	"READ_ONLY_ADMIN",
               	"REPORT_ADMIN",
               	"SUPER_ADMIN",
               	"USER_ADMIN"
               	. See [API Docs](https://developer.okta.com/docs/api/openapi/okta-management/guides/roles/#standard-roles).
               	- "USER_ADMIN" is the Group Administrator.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] target_app_lists: A list of app names (name represents set of app instances, like 'salesforce' or 'facebook'), or a combination of app name and app instance ID (like 'facebook.0oapsqQ6dv19pqyEo0g3') you would like as the targets of the admin role. - Only supported when used with the role type `APP_ADMIN`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] target_group_lists: A list of group IDs you would like as the targets of the admin role. - Only supported when used with the role types: `GROUP_MEMBERSHIP_ADMIN`, `HELP_DESK_ADMIN`, or `USER_ADMIN`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RoleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Assigns Admin roles to Okta Groups. This resource allows you to assign Okta administrator roles to Okta Groups. This resource provides a one-to-one interface between the Okta group and the admin role.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta
        import pulumi_std as std

        example = okta.group.Role("example",
            group_id="<group id>",
            role_type="READ_ONLY_ADMIN")
        # Example for CUSTOM role
        test = okta.group.Group("test",
            name="testAcc_replace_with_uuid",
            description="testing")
        test_resource_set = okta.ResourceSet("test",
            label="test",
            description="testing, testing",
            resources=[std.index.format(input="%s/api/v1/users",
                args=["https://tien-oie-2023-26-26.oktapreview.com"])["result"]])
        test_admin_role_custom = okta.AdminRoleCustom("test",
            label="testt",
            description="testing, testing",
            permissions=[
                "okta.apps.assignment.manage",
                "okta.users.manage",
                "okta.apps.manage",
            ])
        test_role = okta.group.Role("test",
            group_id=test.id,
            role_id=test_admin_role_custom.id,
            resource_set_id=test_resource_set.id,
            role_type="CUSTOM")
        ```

        ## Import

        ```sh
        $ pulumi import okta:group/role:Role example <group_id>/<role_id>
        ```

        :param str resource_name: The name of the resource.
        :param RoleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RoleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disable_notifications: Optional[pulumi.Input[_builtins.bool]] = None,
                 group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_set_id: Optional[pulumi.Input[_builtins.str]] = None,
                 role_id: Optional[pulumi.Input[_builtins.str]] = None,
                 role_type: Optional[pulumi.Input[_builtins.str]] = None,
                 target_app_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 target_group_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RoleArgs.__new__(RoleArgs)

            __props__.__dict__["disable_notifications"] = disable_notifications
            if group_id is None and not opts.urn:
                raise TypeError("Missing required property 'group_id'")
            __props__.__dict__["group_id"] = group_id
            __props__.__dict__["resource_set_id"] = resource_set_id
            __props__.__dict__["role_id"] = role_id
            if role_type is None and not opts.urn:
                raise TypeError("Missing required property 'role_type'")
            __props__.__dict__["role_type"] = role_type
            __props__.__dict__["target_app_lists"] = target_app_lists
            __props__.__dict__["target_group_lists"] = target_group_lists
        super(Role, __self__).__init__(
            'okta:group/role:Role',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            disable_notifications: Optional[pulumi.Input[_builtins.bool]] = None,
            group_id: Optional[pulumi.Input[_builtins.str]] = None,
            resource_set_id: Optional[pulumi.Input[_builtins.str]] = None,
            role_id: Optional[pulumi.Input[_builtins.str]] = None,
            role_type: Optional[pulumi.Input[_builtins.str]] = None,
            target_app_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            target_group_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'Role':
        """
        Get an existing Role resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] disable_notifications: When this setting is enabled, the admins won't receive any of the default Okta administrator emails. These admins also won't have access to contact Okta Support and open support cases on behalf of your org.
        :param pulumi.Input[_builtins.str] group_id: ID of group to attach admin roles to
        :param pulumi.Input[_builtins.str] resource_set_id: Resource Set ID. Required for role_type = `CUSTOM`
        :param pulumi.Input[_builtins.str] role_id: Role ID. Required for role_type = `CUSTOM`
        :param pulumi.Input[_builtins.str] role_type: Admin role assigned to the group. It can be any one of the following values:
               	"API_ADMIN",
               	"APP_ADMIN",
               	"CUSTOM",
               	"GROUP_MEMBERSHIP_ADMIN",
               	"HELP_DESK_ADMIN",
               	"MOBILE_ADMIN",
               	"ORG_ADMIN",
               	"READ_ONLY_ADMIN",
               	"REPORT_ADMIN",
               	"SUPER_ADMIN",
               	"USER_ADMIN"
               	. See [API Docs](https://developer.okta.com/docs/api/openapi/okta-management/guides/roles/#standard-roles).
               	- "USER_ADMIN" is the Group Administrator.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] target_app_lists: A list of app names (name represents set of app instances, like 'salesforce' or 'facebook'), or a combination of app name and app instance ID (like 'facebook.0oapsqQ6dv19pqyEo0g3') you would like as the targets of the admin role. - Only supported when used with the role type `APP_ADMIN`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] target_group_lists: A list of group IDs you would like as the targets of the admin role. - Only supported when used with the role types: `GROUP_MEMBERSHIP_ADMIN`, `HELP_DESK_ADMIN`, or `USER_ADMIN`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RoleState.__new__(_RoleState)

        __props__.__dict__["disable_notifications"] = disable_notifications
        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["resource_set_id"] = resource_set_id
        __props__.__dict__["role_id"] = role_id
        __props__.__dict__["role_type"] = role_type
        __props__.__dict__["target_app_lists"] = target_app_lists
        __props__.__dict__["target_group_lists"] = target_group_lists
        return Role(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="disableNotifications")
    def disable_notifications(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        When this setting is enabled, the admins won't receive any of the default Okta administrator emails. These admins also won't have access to contact Okta Support and open support cases on behalf of your org.
        """
        return pulumi.get(self, "disable_notifications")

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of group to attach admin roles to
        """
        return pulumi.get(self, "group_id")

    @_builtins.property
    @pulumi.getter(name="resourceSetId")
    def resource_set_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Resource Set ID. Required for role_type = `CUSTOM`
        """
        return pulumi.get(self, "resource_set_id")

    @_builtins.property
    @pulumi.getter(name="roleId")
    def role_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Role ID. Required for role_type = `CUSTOM`
        """
        return pulumi.get(self, "role_id")

    @_builtins.property
    @pulumi.getter(name="roleType")
    def role_type(self) -> pulumi.Output[_builtins.str]:
        """
        Admin role assigned to the group. It can be any one of the following values:
        	"API_ADMIN",
        	"APP_ADMIN",
        	"CUSTOM",
        	"GROUP_MEMBERSHIP_ADMIN",
        	"HELP_DESK_ADMIN",
        	"MOBILE_ADMIN",
        	"ORG_ADMIN",
        	"READ_ONLY_ADMIN",
        	"REPORT_ADMIN",
        	"SUPER_ADMIN",
        	"USER_ADMIN"
        	. See [API Docs](https://developer.okta.com/docs/api/openapi/okta-management/guides/roles/#standard-roles).
        	- "USER_ADMIN" is the Group Administrator.
        """
        return pulumi.get(self, "role_type")

    @_builtins.property
    @pulumi.getter(name="targetAppLists")
    def target_app_lists(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        A list of app names (name represents set of app instances, like 'salesforce' or 'facebook'), or a combination of app name and app instance ID (like 'facebook.0oapsqQ6dv19pqyEo0g3') you would like as the targets of the admin role. - Only supported when used with the role type `APP_ADMIN`.
        """
        return pulumi.get(self, "target_app_lists")

    @_builtins.property
    @pulumi.getter(name="targetGroupLists")
    def target_group_lists(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        A list of group IDs you would like as the targets of the admin role. - Only supported when used with the role types: `GROUP_MEMBERSHIP_ADMIN`, `HELP_DESK_ADMIN`, or `USER_ADMIN`.
        """
        return pulumi.get(self, "target_group_lists")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetFeaturesResult',
    'AwaitableGetFeaturesResult',
    'get_features',
    'get_features_output',
]

@pulumi.output_type
class GetFeaturesResult:
    """
    A collection of values returned by getFeatures.
    """
    def __init__(__self__, app_id=None, capabilities=None, description=None, id=None, name=None, status=None):
        if app_id and not isinstance(app_id, str):
            raise TypeError("Expected argument 'app_id' to be a str")
        pulumi.set(__self__, "app_id", app_id)
        if capabilities and not isinstance(capabilities, dict):
            raise TypeError("Expected argument 'capabilities' to be a dict")
        pulumi.set(__self__, "capabilities", capabilities)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> _builtins.str:
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter
    def capabilities(self) -> Optional['outputs.GetFeaturesCapabilitiesResult']:
        """
        A block containing the feature capabilities configuration. See Capabilities below.
        """
        return pulumi.get(self, "capabilities")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the feature.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier of the app feature.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        (String) Status of the import schedule. Valid values are `ENABLED` or `DISABLED`.
        """
        return pulumi.get(self, "status")


class AwaitableGetFeaturesResult(GetFeaturesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFeaturesResult(
            app_id=self.app_id,
            capabilities=self.capabilities,
            description=self.description,
            id=self.id,
            name=self.name,
            status=self.status)


def get_features(app_id: Optional[_builtins.str] = None,
                 capabilities: Optional[Union['GetFeaturesCapabilitiesArgs', 'GetFeaturesCapabilitiesArgsDict']] = None,
                 name: Optional[_builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFeaturesResult:
    """
    Retrieves a Feature object for an app.

    ## Example Usage

    ### Basic Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.app.get_features(app_id="0oarblaf7hWdLawNg1d7",
        name="INBOUND_PROVISIONING")
    ```

    ### User Provisioning Feature

    ```python
    import pulumi
    import pulumi_okta as okta

    user_provisioning = okta.app.get_features(app_id=example["id"],
        name="USER_PROVISIONING")
    pulumi.export("provisioningStatus", user_provisioning.status)
    pulumi.export("passwordSyncEnabled", user_provisioning.capabilities.update.password.status)
    ```

    ### Inbound Provisioning Feature

    ```python
    import pulumi
    import pulumi_okta as okta

    inbound_provisioning = okta.app.get_features(app_id=example["id"],
        name="INBOUND_PROVISIONING")
    pulumi.export("importScheduleStatus", inbound_provisioning.capabilities.import_settings.schedule.status)
    pulumi.export("autoActivateUsers", inbound_provisioning.capabilities.import_rules.user_create_and_match.auto_activate_new_users)
    ```


    :param _builtins.str app_id: The ID of the application to retrieve features for.
    :param Union['GetFeaturesCapabilitiesArgs', 'GetFeaturesCapabilitiesArgsDict'] capabilities: A block containing the feature capabilities configuration. See Capabilities below.
    :param _builtins.str name: The name of the feature to retrieve. Valid values include:
           * `USER_PROVISIONING` - User profiles are pushed from Okta to the third-party app.
           * `INBOUND_PROVISIONING` - User profiles are imported from the third-party app into Okta.
    """
    __args__ = dict()
    __args__['appId'] = app_id
    __args__['capabilities'] = capabilities
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:app/getFeatures:getFeatures', __args__, opts=opts, typ=GetFeaturesResult).value

    return AwaitableGetFeaturesResult(
        app_id=pulumi.get(__ret__, 'app_id'),
        capabilities=pulumi.get(__ret__, 'capabilities'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        status=pulumi.get(__ret__, 'status'))
def get_features_output(app_id: Optional[pulumi.Input[_builtins.str]] = None,
                        capabilities: Optional[pulumi.Input[Optional[Union['GetFeaturesCapabilitiesArgs', 'GetFeaturesCapabilitiesArgsDict']]]] = None,
                        name: Optional[pulumi.Input[_builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFeaturesResult]:
    """
    Retrieves a Feature object for an app.

    ## Example Usage

    ### Basic Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.app.get_features(app_id="0oarblaf7hWdLawNg1d7",
        name="INBOUND_PROVISIONING")
    ```

    ### User Provisioning Feature

    ```python
    import pulumi
    import pulumi_okta as okta

    user_provisioning = okta.app.get_features(app_id=example["id"],
        name="USER_PROVISIONING")
    pulumi.export("provisioningStatus", user_provisioning.status)
    pulumi.export("passwordSyncEnabled", user_provisioning.capabilities.update.password.status)
    ```

    ### Inbound Provisioning Feature

    ```python
    import pulumi
    import pulumi_okta as okta

    inbound_provisioning = okta.app.get_features(app_id=example["id"],
        name="INBOUND_PROVISIONING")
    pulumi.export("importScheduleStatus", inbound_provisioning.capabilities.import_settings.schedule.status)
    pulumi.export("autoActivateUsers", inbound_provisioning.capabilities.import_rules.user_create_and_match.auto_activate_new_users)
    ```


    :param _builtins.str app_id: The ID of the application to retrieve features for.
    :param Union['GetFeaturesCapabilitiesArgs', 'GetFeaturesCapabilitiesArgsDict'] capabilities: A block containing the feature capabilities configuration. See Capabilities below.
    :param _builtins.str name: The name of the feature to retrieve. Valid values include:
           * `USER_PROVISIONING` - User profiles are pushed from Okta to the third-party app.
           * `INBOUND_PROVISIONING` - User profiles are imported from the third-party app into Okta.
    """
    __args__ = dict()
    __args__['appId'] = app_id
    __args__['capabilities'] = capabilities
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:app/getFeatures:getFeatures', __args__, opts=opts, typ=GetFeaturesResult)
    return __ret__.apply(lambda __response__: GetFeaturesResult(
        app_id=pulumi.get(__response__, 'app_id'),
        capabilities=pulumi.get(__response__, 'capabilities'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetServerClientsResult',
    'AwaitableGetServerClientsResult',
    'get_server_clients',
    'get_server_clients_output',
]

@pulumi.output_type
class GetServerClientsResult:
    """
    A collection of values returned by getServerClients.
    """
    def __init__(__self__, auth_server_id=None, client_id=None, created=None, expires_at=None, id=None, issuer=None, last_updated=None, scopes=None, status=None, user_id=None):
        if auth_server_id and not isinstance(auth_server_id, str):
            raise TypeError("Expected argument 'auth_server_id' to be a str")
        pulumi.set(__self__, "auth_server_id", auth_server_id)
        if client_id and not isinstance(client_id, str):
            raise TypeError("Expected argument 'client_id' to be a str")
        pulumi.set(__self__, "client_id", client_id)
        if created and not isinstance(created, str):
            raise TypeError("Expected argument 'created' to be a str")
        pulumi.set(__self__, "created", created)
        if expires_at and not isinstance(expires_at, str):
            raise TypeError("Expected argument 'expires_at' to be a str")
        pulumi.set(__self__, "expires_at", expires_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if issuer and not isinstance(issuer, str):
            raise TypeError("Expected argument 'issuer' to be a str")
        pulumi.set(__self__, "issuer", issuer)
        if last_updated and not isinstance(last_updated, str):
            raise TypeError("Expected argument 'last_updated' to be a str")
        pulumi.set(__self__, "last_updated", last_updated)
        if scopes and not isinstance(scopes, list):
            raise TypeError("Expected argument 'scopes' to be a list")
        pulumi.set(__self__, "scopes", scopes)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="authServerId")
    def auth_server_id(self) -> _builtins.str:
        """
        The ID of the authorization server.
        """
        return pulumi.get(self, "auth_server_id")

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> _builtins.str:
        """
        The client ID of the app.
        """
        return pulumi.get(self, "client_id")

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.str:
        """
        Timestamp when the object was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> _builtins.str:
        """
        Expiration time of the OAuth 2.0 Token.
        """
        return pulumi.get(self, "expires_at")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the token.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def issuer(self) -> _builtins.str:
        """
        The complete URL of the authorization server that issued the Token
        """
        return pulumi.get(self, "issuer")

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> _builtins.str:
        """
        Timestamp when the object was last updated.
        """
        return pulumi.get(self, "last_updated")

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> Sequence[_builtins.str]:
        """
        The scope names attached to the Token.
        """
        return pulumi.get(self, "scopes")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The status URI of the OAuth 2.0 application.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> _builtins.str:
        """
        The ID of the user associated with the Token.
        """
        return pulumi.get(self, "user_id")


class AwaitableGetServerClientsResult(GetServerClientsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServerClientsResult(
            auth_server_id=self.auth_server_id,
            client_id=self.client_id,
            created=self.created,
            expires_at=self.expires_at,
            id=self.id,
            issuer=self.issuer,
            last_updated=self.last_updated,
            scopes=self.scopes,
            status=self.status,
            user_id=self.user_id)


def get_server_clients(auth_server_id: Optional[_builtins.str] = None,
                       client_id: Optional[_builtins.str] = None,
                       id: Optional[_builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServerClientsResult:
    """
    Get OAuth 2.0 refresh token information for an authorization server client from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.auth.get_server_clients(id="oar123456abcdefghijklm",
        auth_server_id="aus123456abcdefghijklm",
        client_id="0oa123456abcdefghijklm")
    ```


    :param _builtins.str auth_server_id: The ID of the authorization server.
    :param _builtins.str client_id: The client ID of the app.
    :param _builtins.str id: The ID of the token.
    """
    __args__ = dict()
    __args__['authServerId'] = auth_server_id
    __args__['clientId'] = client_id
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:auth/getServerClients:getServerClients', __args__, opts=opts, typ=GetServerClientsResult).value

    return AwaitableGetServerClientsResult(
        auth_server_id=pulumi.get(__ret__, 'auth_server_id'),
        client_id=pulumi.get(__ret__, 'client_id'),
        created=pulumi.get(__ret__, 'created'),
        expires_at=pulumi.get(__ret__, 'expires_at'),
        id=pulumi.get(__ret__, 'id'),
        issuer=pulumi.get(__ret__, 'issuer'),
        last_updated=pulumi.get(__ret__, 'last_updated'),
        scopes=pulumi.get(__ret__, 'scopes'),
        status=pulumi.get(__ret__, 'status'),
        user_id=pulumi.get(__ret__, 'user_id'))
def get_server_clients_output(auth_server_id: Optional[pulumi.Input[_builtins.str]] = None,
                              client_id: Optional[pulumi.Input[_builtins.str]] = None,
                              id: Optional[pulumi.Input[_builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetServerClientsResult]:
    """
    Get OAuth 2.0 refresh token information for an authorization server client from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.auth.get_server_clients(id="oar123456abcdefghijklm",
        auth_server_id="aus123456abcdefghijklm",
        client_id="0oa123456abcdefghijklm")
    ```


    :param _builtins.str auth_server_id: The ID of the authorization server.
    :param _builtins.str client_id: The client ID of the app.
    :param _builtins.str id: The ID of the token.
    """
    __args__ = dict()
    __args__['authServerId'] = auth_server_id
    __args__['clientId'] = client_id
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:auth/getServerClients:getServerClients', __args__, opts=opts, typ=GetServerClientsResult)
    return __ret__.apply(lambda __response__: GetServerClientsResult(
        auth_server_id=pulumi.get(__response__, 'auth_server_id'),
        client_id=pulumi.get(__response__, 'client_id'),
        created=pulumi.get(__response__, 'created'),
        expires_at=pulumi.get(__response__, 'expires_at'),
        id=pulumi.get(__response__, 'id'),
        issuer=pulumi.get(__response__, 'issuer'),
        last_updated=pulumi.get(__response__, 'last_updated'),
        scopes=pulumi.get(__response__, 'scopes'),
        status=pulumi.get(__response__, 'status'),
        user_id=pulumi.get(__response__, 'user_id')))
